@@ -344,7 +344,8 @@ def ClusteringProteinSeqiences(VicinityFASTAFileName=os.path.join("./" + "RM_A"+
 
     subprocess_call("Step 9: Clustering protein seqiences", "bash " +BASE_DIR+ "/RunClust.sh " + VicinityFASTAFileName + " " +
                 str(PermissiveClusteringThreshold) + " " +
-                VicinityClustersFileName)
+                VicinityClustersFileName + " "+
+                BASE_DIR)
 
 
 # step 10
